@@ -1,29 +1,9 @@
-/** ===========================================================
- * @file
- *
- * This file is a part of KDE project
- *
- *
- * @date   2007-09-03
- * @brief  Exiv2 library interface for KDE
- *
- * @author Copyright (C) 2006-2015 by Gilles Caulier
- *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
- * @author Copyright (C) 2006-2012 by Marcel Wiesweg
- *         <a href="mailto:marcel dot wiesweg at gmx dot de">marcel dot wiesweg at gmx dot de</a>
- *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * ============================================================ */
+/*
+    SPDX-FileCopyrightText: 2006-2015 Gilles Caulier <caulier dot gilles at gmail dot com>
+    SPDX-FileCopyrightText: 2006-2012 Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kexiv2_p.h"
 
@@ -62,22 +42,20 @@ extern "C"
 namespace KExiv2Iface
 {
 
-KExiv2::Private::Private()
-    : data(new KExiv2Data::Private)
+KExiv2Private::KExiv2Private()
+    : data(new KExiv2DataPrivate)
 {
     writeRawFiles         = false;
     updateFileTimeStamp   = false;
     useXMPSidecar4Reading = false;
-    metadataWritingMode   = WRITETOIMAGEONLY;
+    metadataWritingMode   = KExiv2::WRITETOIMAGEONLY;
     loadedFromSidecar     = false;
-    Exiv2::LogMsg::setHandler(KExiv2::Private::printExiv2MessageHandler);
+    Exiv2::LogMsg::setHandler(KExiv2Private::printExiv2MessageHandler);
 }
 
-KExiv2::Private::~Private()
-{
-}
+KExiv2Private::~KExiv2Private() = default;
 
-void KExiv2::Private::copyPrivateData(const Private* const other)
+void KExiv2Private::copyPrivateData(const KExiv2Private* const other)
 {
     data                  = other->data;
     filePath              = other->filePath;
@@ -87,7 +65,7 @@ void KExiv2::Private::copyPrivateData(const Private* const other)
     metadataWritingMode   = other->metadataWritingMode;
 }
 
-bool KExiv2::Private::saveToXMPSidecar(const QFileInfo& finfo) const
+bool KExiv2Private::saveToXMPSidecar(const QFileInfo& finfo) const
 {
     QString filePath = KExiv2::sidecarFilePathForFile(finfo.filePath());
 
@@ -98,9 +76,17 @@ bool KExiv2::Private::saveToXMPSidecar(const QFileInfo& finfo) const
 
     try
     {
+#if EXIV2_TEST_VERSION(0,28,0)
+        Exiv2::Image::UniquePtr image;
+#else
         Exiv2::Image::AutoPtr image;
+#endif
         image = Exiv2::ImageFactory::create(Exiv2::ImageType::xmp, (const char*)(QFile::encodeName(filePath).constData()));
+#if EXIV2_TEST_VERSION(0,28,0)
+        return saveOperations(finfo, std::move(image));
+#else
         return saveOperations(finfo, image);
+#endif
     }
     catch( Exiv2::Error& e )
     {
@@ -114,7 +100,7 @@ bool KExiv2::Private::saveToXMPSidecar(const QFileInfo& finfo) const
     }
 }
 
-bool KExiv2::Private::saveToFile(const QFileInfo& finfo) const
+bool KExiv2Private::saveToFile(const QFileInfo& finfo) const
 {
     if (!finfo.isWritable())
     {
@@ -177,9 +163,17 @@ bool KExiv2::Private::saveToFile(const QFileInfo& finfo) const
 
     try
     {
+#if EXIV2_TEST_VERSION(0,28,0)
+        Exiv2::Image::UniquePtr image;
+#else
         Exiv2::Image::AutoPtr image;
+#endif
         image = Exiv2::ImageFactory::open((const char*)(QFile::encodeName(finfo.filePath()).constData()));
+#if EXIV2_TEST_VERSION(0,28,0)
+        return saveOperations(finfo, std::move(image));
+#else
         return saveOperations(finfo, image);
+#endif
     }
     catch( Exiv2::Error& e )
     {
@@ -193,7 +187,11 @@ bool KExiv2::Private::saveToFile(const QFileInfo& finfo) const
     }
 }
 
-bool KExiv2::Private::saveOperations(const QFileInfo& finfo, Exiv2::Image::AutoPtr image) const
+#if EXIV2_TEST_VERSION(0,28,0)
+bool KExiv2Private::saveOperations(const QFileInfo& finfo, Exiv2::Image::UniquePtr image) const
+#else
+bool KExiv2Private::saveOperations(const QFileInfo& finfo, Exiv2::Image::AutoPtr image) const
+#endif
 {
     try
     {
@@ -353,7 +351,7 @@ bool KExiv2::Private::saveOperations(const QFileInfo& finfo, Exiv2::Image::AutoP
     return false;
 }
 
-void KExiv2Data::Private::clear()
+void KExiv2DataPrivate::clear()
 {
     imageComments.clear();
     exifMetadata.clear();
@@ -363,19 +361,24 @@ void KExiv2Data::Private::clear()
 #endif
 }
 
-void KExiv2::Private::printExiv2ExceptionError(const QString& msg, Exiv2::Error& e)
+void KExiv2Private::printExiv2ExceptionError(const QString& msg, Exiv2::Error& e)
 {
     std::string s(e.what());
     qCCritical(LIBKEXIV2_LOG) << msg.toLatin1().constData() << " (Error #"
-                              << e.code() << ": " << s.c_str();
+#if EXIV2_TEST_VERSION(0,28,0)
+                              << Exiv2::Error(e.code()).what()
+#else
+                              << e.code() << ": " << s.c_str()
+#endif
+                              << ")";
 }
 
-void KExiv2::Private::printExiv2MessageHandler(int lvl, const char* msg)
+void KExiv2Private::printExiv2MessageHandler(int lvl, const char* msg)
 {
     qCDebug(LIBKEXIV2_LOG) << "Exiv2 (" << lvl << ") : " << msg;
 }
 
-QString KExiv2::Private::convertCommentValue(const Exiv2::Exifdatum& exifDatum) const
+QString KExiv2Private::convertCommentValue(const Exiv2::Exifdatum& exifDatum) const
 {
     try
     {
@@ -430,7 +433,7 @@ QString KExiv2::Private::convertCommentValue(const Exiv2::Exifdatum& exifDatum)
     return QString();
 }
 
-QString KExiv2::Private::detectEncodingAndDecode(const std::string& value) const
+QString KExiv2Private::detectEncodingAndDecode(const std::string& value) const
 {
     // For charset autodetection, we could use sophisticated code
     // (Mozilla chardet, KHTML's autodetection, QTextCodec::codecForContent),
@@ -456,10 +459,10 @@ QString KExiv2::Private::detectEncodingAndDecode(const std::string& value) const
     return QString::fromLocal8Bit(value.c_str());
 }
 
-bool KExiv2::Private::isUtf8(const char* const buffer) const
+bool KExiv2Private::isUtf8(const char* const buffer) const
 {
     int i, n;
-    register unsigned char c;
+    unsigned char c;
     bool gotone = false;
 
     if (!buffer)
@@ -575,7 +578,7 @@ done:
 #undef I
 #undef X
 
-int KExiv2::Private::getXMPTagsListFromPrefix(const QString& pf, KExiv2::TagsMap& tagsMap) const
+int KExiv2Private::getXMPTagsListFromPrefix(const QString& pf, KExiv2::TagsMap& tagsMap) const
 {
     int i = 0;
 
@@ -621,7 +624,11 @@ int KExiv2::Private::getXMPTagsListFromPrefix(const QString& pf, KExiv2::TagsMap
 }
 
 #ifdef _XMP_SUPPORT_
-void KExiv2::Private::loadSidecarData(Exiv2::Image::AutoPtr xmpsidecar)
+#if EXIV2_TEST_VERSION(0,28,0)
+void KExiv2Private::loadSidecarData(Exiv2::Image::UniquePtr xmpsidecar)
+#else
+void KExiv2Private::loadSidecarData(Exiv2::Image::AutoPtr xmpsidecar)
+#endif
 {
     // Having a sidecar is a special situation.
     // The sidecar data often "dominates", see in particular bug 309058 for important aspects:
